Struct parquet::memory::Buffer[][src]

pub struct Buffer<T: Clone> { /* fields omitted */ }

A resize-able buffer class with generic member, with optional memory tracker.

Note that a buffer has two attributes: capacity and size: the former is the total number of space reserved for the buffer, while the latter is the actual number of elements. Invariant: capacity >= size. The total allocated bytes for a buffer equals to capacity * sizeof<T>().

Methods

impl<T: Clone> Buffer<T>
[src]

Creates new empty buffer.

Adds MemTracker for this buffer.

Returns slice of data in this buffer.

Sets data for this buffer.

Resizes underlying data in place to a new length new_size.

If new_size is less than current length, data is truncated, otherwise, it is extended to new_size with provided default value init_value.

Memory tracker is also updated, if available.

Clears underlying data.

Reserves capacity additional_capacity for underlying data vector.

Memory tracker is also updated, if available.

Returns BufferPtr with buffer data. Buffer data is reset.

Adds value to the buffer.

Returns current capacity for the buffer.

Returns current size for the buffer.

Returns true if memory tracker is added to buffer, false otherwise.

Returns memory tracker associated with this buffer. This may panic, if memory tracker is not set, use method above to check if memory tracker is available.