Struct parquet::memory::BufferPtr[][src]

pub struct BufferPtr<T> { /* fields omitted */ }

An representation of a slice on a reference-counting and read-only byte array. Sub-slices can be further created from this. The byte array will be released when all slices are dropped.

Methods

impl<T> BufferPtr<T>
[src]

Creates new buffer from a vector.

Returns slice of data in this buffer.

Updates this buffer with new start position and length len.

Range should be within current start position and length.

Adds memory tracker to this buffer.

Returns start position of this buffer.

Returns length of this buffer

Returns true if this buffer has memory tracker, false otherwise.

Returns a shallow copy of the buffer. Reference counted pointer to the data is copied.

Returns a shallow copy of the buffer that starts with start position.

Returns a shallow copy that is a range slice within this buffer.