Struct parquet::memory::MemTracker[][src]

pub struct MemTracker { /* fields omitted */ }

Struct to track memory usage information.

Methods

impl MemTracker
[src]

Creates new memory tracker.

Returns the current memory consumption, in bytes.

Returns the maximum memory consumption so far, in bytes.

Adds num_bytes to the memory consumption tracked by this memory tracker.